/**
 * Measure coverage and save report to file.
 * @memberof module:ap-covering/lib
 * @function measureCoverage
 * @param {string} script - JavaScript script to measure
 * @param {string[]} scriptArgs - Arguments to pass script.
 * @param {object} {object} [options] - Optional settings.
 * @param {string} [options.dir='coverage'] - Directory path to save.
 */

"use strict";

var argx = require('argx'),
    childProcess = require('child_process');

var istanbulBin = require.resolve('istanbul/lib/cli');

/** @lends measureCoverage */
function measureCoverage(script, scriptArgs, options, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    script = args.shift('string');
    scriptArgs = [].concat(args.shift('string|array') || []);
    options = args.pop('object') || {};

    var spawnArgs = ['cover', '--dir', options.dir || 'coverage', script, '--'].concat(scriptArgs);

    var istanbul = childProcess.spawn(istanbulBin, spawnArgs, {
            stdio: [
                0,
                process.stdout,
                process.stderr
            ]
        }
    );
    istanbul.on('exit', function (code) {
        var err = code === 0 ? null : new Error('Exit with code:' + code);
        callback(err);
    });
}

module.exports = measureCoverage;


